class Foo(BaseModel):
    name = StringField()
    # ....
    name = StringField()  # PIE794

    def remove(self) -> None:
        ...


class Foo(BaseModel):
    name: str = StringField()
    # ....
    name = StringField()  # PIE794

    def foo(self) -> None:
        ...


class User(BaseModel):
    bar: str = StringField()
    foo: bool = BooleanField()
    # ...
    bar = StringField()  # PIE794


class User(BaseModel):
    @property
    def buzz(self) -> str:
        ...

    @buzz.setter
    def buzz(self, value: str | int) -> None:
        ...


class User:
    bar: str = StringField()
    foo: bool = BooleanField()
    # ...
    bar = StringField()  # PIE794


class Person:
    name = "Foo"
    name = name + " Bar"
    name = "Bar"  # PIE794


class Person:
    name: str = "Foo"
    name: str = name + " Bar"
    name: str = "Bar"  # PIE794


class TextEdit:
    start_line: int
    start_line: int  # PIE794
